==> of_v0.7.4_ios_release.zip: of_v0.7.4_ios_release/addons/ofxMultiTouch/src/ofxMultiTouch.h <==
/***********************************************************************
 
 Copyright (c) 2008, 2009, Memo Akten, www.memo.tv
 *** The Mega Super Awesome Visuals Company ***
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of MSA Visuals nor the names of its contributors 
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
 * ***********************************************************************/ 


#pragma once

#include "ofMain.h"
#include "ofxMultiTouchListener.h"

class ofxMultiTouchHandler : public ofxMultiTouchListener {
public:
	void addListener(ofxMultiTouchListener* o) {
//		listeners.push_back(o);
//		o->registerTouchEvents();
		ofAddListener(ofEvents().touchDown, o, &ofxMultiTouchListener::_touchDown);
		ofAddListener(ofEvents().touchUp, o, &ofxMultiTouchListener::_touchUp);
		ofAddListener(ofEvents().touchMoved, o, &ofxMultiTouchListener::_touchMoved);
		ofAddListener(ofEvents().touchDoubleTap, o, &ofxMultiTouchListener::_touchDoubleTap);
		ofAddListener(ofEvents().touchCancelled, o, &ofxMultiTouchListener::_touchCancelled);
	}
	
	void removeListener(ofxMultiTouchListener* o) {
//		listeners.remove(o);
//		o->unregisterTouchEvents();
		ofRemoveListener(ofEvents().touchDown, o, &ofxMultiTouchListener::_touchDown);
		ofRemoveListener(ofEvents().touchUp, o, &ofxMultiTouchListener::_touchUp);
		ofRemoveListener(ofEvents().touchMoved, o, &ofxMultiTouchListener::_touchMoved);
		ofRemoveListener(ofEvents().touchDoubleTap, o, &ofxMultiTouchListener::_touchDoubleTap);
		ofRemoveListener(ofEvents().touchCancelled, o, &ofxMultiTouchListener::_touchCancelled);
	}
	
	
};

class ofxiPhoneApp;

void ofxRegisterMultitouch(ofxiPhoneApp * app);
void ofxUnregisterMultitouch(ofxiPhoneApp * app);

extern ofxMultiTouchHandler ofxMultiTouch;

==> of_v0.8.0_ios_release.zip: of_v0.8.0_ios_release/addons/ofxMultiTouch/src/ofxMultiTouch.h <==
/***********************************************************************
 
 Copyright (c) 2008, 2009, Memo Akten, www.memo.tv
 *** The Mega Super Awesome Visuals Company ***
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of MSA Visuals nor the names of its contributors 
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
 * ***********************************************************************/ 


#pragma once

#include "ofMain.h"
#include "ofxMultiTouchListener.h"

class ofxMultiTouchHandler : public ofxMultiTouchListener {
public:
	void addListener(ofxMultiTouchListener* o) {
//		listeners.push_back(o);
//		o->registerTouchEvents();
		ofAddListener(ofEvents().touchDown, o, &ofxMultiTouchListener::_touchDown);
		ofAddListener(ofEvents().touchUp, o, &ofxMultiTouchListener::_touchUp);
		ofAddListener(ofEvents().touchMoved, o, &ofxMultiTouchListener::_touchMoved);
		ofAddListener(ofEvents().touchDoubleTap, o, &ofxMultiTouchListener::_touchDoubleTap);
		ofAddListener(ofEvents().touchCancelled, o, &ofxMultiTouchListener::_touchCancelled);
	}
	
	void removeListener(ofxMultiTouchListener* o) {
//		listeners.remove(o);
//		o->unregisterTouchEvents();
		ofRemoveListener(ofEvents().touchDown, o, &ofxMultiTouchListener::_touchDown);
		ofRemoveListener(ofEvents().touchUp, o, &ofxMultiTouchListener::_touchUp);
		ofRemoveListener(ofEvents().touchMoved, o, &ofxMultiTouchListener::_touchMoved);
		ofRemoveListener(ofEvents().touchDoubleTap, o, &ofxMultiTouchListener::_touchDoubleTap);
		ofRemoveListener(ofEvents().touchCancelled, o, &ofxMultiTouchListener::_touchCancelled);
	}
	
	
};

class ofxiOSApp;

void ofxRegisterMultitouch(ofxiOSApp * app);
void ofxUnregisterMultitouch(ofxiOSApp * app);

extern ofxMultiTouchHandler ofxMultiTouch;
